' =========================================================
' Beceem script function library for CM installers
' =========================================================

' Prototypes for Script_function_library.vbs
'
' Sub CopyFileToFolder(strSrcFilePath, strDestFolder)
' Sub CopyFileToFolderNotify(strSrcFilePath, strDestFolder, bNotifyOnFail)
' Sub CopyFileToFile(strSrcFilePath, strDstFilePath)
' Sub CopyFileToFileNotify(strSrcFilePath, strDestFolder, bNotifyOnFail, bNotifyOnNotExists)
' Sub CopyDll(strDllName, strDestFolder)
' Sub CopyDllNotify(strDllName, strDestFolder, bNotifyOnFail)
' Sub CreateFolder(strFolderName)
' Sub CreateFolderNotify(strFolderName, bNotifyOnFail, bNotifyOnExists)
' Sub CopyFolder(strSrcFolder, strDstFolder)
' Sub CopyFolderNotify(strSrcFolder, strDstFolder, bNotifyOnFail)
' Sub CleanProject(strSolutionFolder, strProjectName)
' Sub CleanSolution(strSolutionFolder)
' Sub DeleteFile(strFilePath)
' Sub DeleteFileNotify(strFilePath, bNotifyOnFail, bNotifyIfMissing)
' Sub DeleteFilePattern(strFilePattern)
' Sub DeleteFilePatternNotify(strFilePattern, bNotifyOnFail)
' Sub DeleteFolder(strFolderPath)
' Sub DeleteFolderNotify(strFolderPath, bNotifyOnFail, bNotifyIfMissing)
' Sub DeleteEmptyFolder(strFolderPath)
' Sub DeleteEmptyFolderNotify(strFolderPath, bNotifyOnFail, bNotifyIfMissing)
' Sub ListFiles(objFolder, intLevel)
' Function OSName()

' The following global variables MUST be defined to use these functions
'     objFSO - file system object

If IsNull(objFSO) Then
	Set objFSO = CreateObject("Scripting.FileSystemObject")
End If

' ---------------------------------------------------------
' Copy a file into a folder with test for missing files
Sub CopyFileToFolder(strSrcFilePath, strDestFolder)
	CopyFileToFolderNotify strSrcFilePath, strDestFolder, False
End Sub 

Sub CopyFileToFolderNotify(strSrcFilePath, strDestFolder, bNotifyOnFail)

	On Error Resume Next
	objFSO.CopyFile strSrcFilePath, strDestFolder
	If Err.Number > 0 Then
		If bNotifyOnFail then
			MsgBox "Can't copy '" & strSrcFilePath & "' to '" & strDestFolder & "'" & vbLf & _
				   "Error #" & CStr(Err.Number) & ": " & Err.Description
		End if
		Err.Clear
	End if
	On Error Goto 0

End Sub

' ---------------------------------------------------------
' Copy a file to another file paht with a test for a missing source file.
Sub CopyFileToFile(strSrcFilePath, strDstFilePath)
	CopyFileToFileNotify strSrcFilePath, strDstFilePath, False, False
End Sub 

Sub CopyFileToFileNotify(strSrcFilePath, strDstFilePath, bNotifyOnFail, bNotifyOnNotExists)

   	If Not objFSO.FileExists(strSrcFilePath) Then
    	If bNotifyOnNotExists Then
    		MsgBox "File " & strSrcFilePath & " does not exist"
    	End if
    Else
		On Error Resume Next	
		objFSO.CopyFile strSrcFilePath, strDstFilePath
		If Err.Number > 0 Then
			If bNotifyOnFail then
				MsgBox "Can't copy '" & strSrcFilePath & "' to '" & strDstFilePath & "'" & vbLf & _
					   "Error #" & CStr(Err.Number) & ": " & Err.Description
			End if
			Err.Clear
		End if
		On Error Goto 0
	End if

End Sub

' ---------------------------------------------------------
' Copy libraries to debug & release folders
Sub CopyDll(strDllName, strDestFolder)
	CopyDllNotify strDllName, strDestFolder, False
End Sub

Sub CopyDllNotify(strDllName, strDestFolder, bNotifyOnFail)

	Dim strSrcFile
	
	CopyFileToFolderNotify strDllName + ".dll", strDestFolder + "debug\", bNotifyOnFail
	CopyFileToFolderNotify strDllName + ".lib", strDestFolder + "debug\", bNotifyOnFail
	CopyFileToFolderNotify strDllName + ".dll", strDestFolder + "release\", bNotifyOnFail
	CopyFileToFolderNotify strDllName + ".lib", strDestFolder + "release\", bNotifyOnFail

End Sub

' ---------------------------------------------------------
' Create a folder 
Sub CreateFolder(strFolderName)
	CreateFolderNotify strFolderName, False, False
End Sub

Sub CreateFolderNotify(strFolderName, bNotifyOnFail, bNotifyOnExists)

    If objFSO.FolderExists(strFolderName) Then
    	If bNotifyOnExists Then
    		MsgBox "Folder " & strFolderName & " already exists"
    	End if
    Else
    	On Error Resume Next
    	objFSO.CreateFolder(strFolderName)
    	If Err.Number <> 0 Then
			If bNotifyIfMissing then
				MsgBox "Folder " & strFolderName & " was not created"
			End if
			Err.Clear
			Exit Sub
		End If
    	
    	On Error Goto 0
    End If

End Sub

' ---------------------------------------------------------
' Copies a folder (with recursion)
Sub CopyFolder(strSrcFolder, strDstFolder)
	CopyFolderNotify strSrcFolder, strDstFolder, False
End Sub

Sub CopyFolderNotify(strSrcFolder, strDstFolder, bNotifyOnFail)
   	
   	On Error Resume Next	
    objFSO.CopyFolder strSrcFolder, strDstFolder, True
    If Err.Number <> 0 Then
		If bNotifyOnFail then
			MsgBox "ERROR on folder copy from '" & strSrcFolder & "' to '" & strDstFolder & "'"
		End if
		Err.Clear
	End If
	On Error Goto 0
	
End sub

' --------------------------------------------------------
' Clean up a project build directory
Sub CleanProject(strSolutionFolder, strProjectName)

	Dim strProjectFolder 
	
	strProjectFolder = strSolutionFolder + strProjectName + "\"
	
	DeleteFilePattern strProjectFolder & strProjectName & ".vcproj*user"
	DeleteFilePattern strProjectFolder & "*.aps"
	DeleteFilePattern strProjectFolder & "*.log"
	DeleteFilePattern strProjectFolder & "*.idb"
	DeleteFolder strProjectFolder & "Debug"
	DeleteFolder strProjectFolder & "Debug-Malloc"
	DeleteFolder strProjectFolder & "Release"
	DeleteEmptyFolder strProjectFolder
	
End Sub

' ---------------------------------------------------------
' Clean up a solution build directory
Sub CleanSolution(strSolutionFolder)

	DeleteFilePattern strSolutionFolder & "*.ncb"
	DeleteFilePattern strSolutionFolder & "*.suo"

	DeleteFolder strSolutionFolder & "debug"
	DeleteFolder strSolutionFolder & "debug-malloc"
	DeleteFolder strSolutionFolder & "release"
	
	DeleteEmptyFolder strSolutionFolder
	
End sub

' ---------------------------------------------------------
' Delete a file
Sub DeleteFile(strFilePath)
	DeleteFileNotify strFilePath, False, False
End Sub

Sub DeleteFileNotify(strFilePath, bNotifyOnFail, bNotifyIfMissing)

	Dim objFile
	
	On Error Resume Next
	
	Set objFile = objFSO.GetFile(strFilePath)
	If Err.Number <> 0 Then
		If bNotifyIfMissing then
			MsgBox "File " & strFilePath & " not found"
		End if
		Err.Clear
	else
		objFile.Delete
		If Err.Number <> 0 Then
			If bNotifyOnFail then
				MsgBox "Can't delete file " & strFilePath
			End If 
			Err.Clear
		End If
	End if

	On Error Goto 0
	
End Sub

' ---------------------------------------------------------
' Delete a file by wildcard

Sub DeleteFilePattern(strFilePattern)
	DeleteFilePatternNotify strFilePattern, False
End Sub

Sub DeleteFilePatternNotify(strFilePattern, bNotifyOnFail)
	
	On Error Resume Next
	
	objFSO.DeleteFile strFilePattern
	If Err.Number <> 0 Then
		If bNotifyOnFail then
			MsgBox "Can't delete file pattern " & strFilePattern
		End if
		Err.Clear
		Exit Sub
	End If
	
	On Error Goto 0
	
End Sub

' ---------------------------------------------------------
' Delete a folder
Sub DeleteFolder(strFolderPath)
	DeleteFolderNotify strFolderPath, False, False
End Sub

Sub DeleteFolderNotify(strFolderPath, bNotifyOnFail, bNotifyIfMissing)

	Dim objFolder
	
	On Error Resume Next
	
	Set objFolder = objFSO.GetFolder(strFolderPath)
	If Err.Number <> 0 Then
		If bNotifyIfMissing then
			MsgBox "Folder " & strFolderPath & " not found"
		End if
		Err.Clear
	else
		objFolder.Delete
		If Err.Number <> 0 Then
			If bNotifyOnFail then
				MsgBox "Can't delete folder " & strFolderPath
			End if
			Err.Clear
		End If
	End if
	
	On Error Goto 0

End Sub

' ---------------------------------------------------------
' Delete a folder only if it's empty
Sub DeleteEmptyFolder(strFolderPath)
	DeleteEmptyFolderNotify strFolderPath, False, False
End Sub

Sub DeleteEmptyFolderNotify(strFolderPath, bNotifyOnFail, bNotifyIfMissing)

	Dim objFolder
	
	On Error Resume Next
	
	Set objFolder = objFSO.GetFolder(strFolderPath)
	If Err.Number <> 0 Then
		If bNotifyIfMissing then
			MsgBox "Folder " & strFolderPath & " not found"
		End if
		Err.Clear
	else
		If objFolder.Files.Count = 0 And objFolder.SubFolders.Count = 0 then
			objFolder.Delete
			If Err.Number <> 0 Then
				If bNotifyOnFail then
					MsgBox "Can't delete folder " & strFolderPath
				End if
				Err.Clear
				Exit Sub
			End If
		End If
	End if
	
	On Error Goto 0

End Sub

' ---------------------------------------------------------
' List the files in a folder
'   intLevel = indentation level (initial call sets intLevel = 0)
Sub ListFiles(objFolder, intLevel)

	Dim objFile
	Dim objSubFolder
	Dim strPrefix
	
	strPrefix = String(4*intLevel+4, " ")
	
	WScript.Echo String(4*intLevel, " ") & objFolder.Name & " Folder "
	
	For Each objFile In objFolder.Files
		WScript.Echo strPrefix & objFile.Name
	Next
	For Each objSubFolder In objFolder.SubFolders
		ListFiles objSubFolder, intLevel + 1
	Next

End Sub

' ---------------------------------------------------------
' Returns the name of the operating system
Function OSName()
	Dim strComputer
	Dim objWMIService
	Dim colOSes
	Dim objOS
	
	OSName = "Unknown"
	
	strComputer = "."
	Set objWMIService = GetObject("winmgmts:" _
	 & "{impersonationLevel=impersonate}!\\" & strComputer & "\root\cimv2")
	 
	Set colOSes = objWMIService.ExecQuery("Select * from Win32_OperatingSystem")
	For Each objOS in colOSes
		If Not IsNull(OSName) And Not IsEmpty(OSName) then
			OSName = objOS.Caption
			Exit Function
		End if
	Next
End Function
