// BeceemEngineTestApp.cpp : Defines the entry point for the console application.
//

#include <stdlib.h>
#include <stdio.h>

#include <openssl/bio.h>
#include <openssl/err.h>
#include <openssl/engine.h>
#include <openssl/ssl.h>

#define BECEEM_ENGINE_SOPATH  "/Beceem/CSCM/App/engine_beceem.dll"
#define BECEEM_ENGINE_ID      "opensc"
#define DYNAMIC_ENGINE_ID     "dynamic"

static BIO *bio_err = NULL;
static BIO *bio_out = NULL;

static int RunTest(void);
static int SendCtrlCmd(ENGINE *e, char *cmd, char *value);
static ENGINE * EngineByID(const char * engine_id);


static int RunTest(void)
	{

	ENGINE *e;
	EVP_PKEY *pkey;
	unsigned long ssl_error_code = 0;

	ENGINE_load_dynamic();
 
	// ---------------------------------------------------
	// Is Beceem engine already loaded?
	// ---------------------------------------------------
	e = ENGINE_by_id(BECEEM_ENGINE_ID);
	if (e != NULL) 
		{
		ENGINE_free(e);
		printf("ENGINE: engine '%s' is already available", BECEEM_ENGINE_ID);
		return 0;
		}
	ERR_clear_error();

	// ---------------------------------------------------
	// Load dynamic engine
	// ---------------------------------------------------
	if ((e = EngineByID(DYNAMIC_ENGINE_ID)) == NULL)
		return -1;

	// ENGINE_ctrl(e, ENGINE_CTRL_SET_LOGSTREAM, 0, bio_err, 0);

	if (SendCtrlCmd(e, "SO_PATH", BECEEM_ENGINE_SOPATH) ||
		SendCtrlCmd(e, "ID", BECEEM_ENGINE_ID)          ||
		SendCtrlCmd(e, "LIST_ADD", "1")					||
		SendCtrlCmd(e, "LOAD", NULL))
		{
		ENGINE_free(e);
		return -1;
		}

	ENGINE_free(e);

	// ---------------------------------------------------
	// Initialize Beceem engine
	// ---------------------------------------------------
	if ((e = EngineByID(BECEEM_ENGINE_ID)) == NULL)
		return -1;

#if 0

	SSL_load_error_strings();

	bio_err=BIO_new_fp(stderr,BIO_NOCLOSE);
	bio_out=BIO_new_fp(stdout,BIO_NOCLOSE);

	BIO_printf(bio_err, "Starting BeceemEngineTestApp\n");

#endif

	if (!ENGINE_init(e)) {
		printf("Error: ENGINE_init() failed, reason %s\n", 
			ERR_error_string(ERR_get_error(), NULL));
		ENGINE_finish(e);
		ENGINE_free(e);
		return -1;
	}

	SendCtrlCmd(e, "PIN", "00000000 00000000 1 'engine_test.log'");
	pkey = ENGINE_load_private_key(e,NULL,0,NULL);

	EVP_PKEY_free(pkey);

	// ---------------------------------------------------
	// De-Initialize Beceem engine
	// ---------------------------------------------------

	ENGINE_finish(e);

	ENGINE_free(e);

	// ---------------------------------------------------
	// Clean up engine system
	// ---------------------------------------------------

	ENGINE_cleanup();

	return 0;

	} // RunTest()

static ENGINE * EngineByID(const char * engine_id)
	{

	ENGINE *e;

	e = ENGINE_by_id(engine_id);
	if (e == NULL) 
		{
		printf("ERROR: Can't find %s engine: %s\n", 
			DYNAMIC_ENGINE_ID,
			ERR_error_string(ERR_get_error(), NULL));
			return NULL;
		}

	ERR_clear_error();

	engine_id = ENGINE_get_id(e);
	printf("Successfuly loaded %s engine\n", engine_id);

	return e;

	}


static int SendCtrlCmd(ENGINE *e, char *cmd, char *value)
	{

	printf("%s : %s ", cmd, value);
	if (ENGINE_ctrl_cmd_string(e, cmd, value, 0) == 0) 
		{
		printf("FAILED\nERROR: command failed: %s\n", ERR_error_string(ERR_get_error(), NULL));
		return -1;
		}
	else
		printf("SUCCESS\n");

	return 0;

	}

int main(int argc, char* argv[])
{

	RunTest();

	RunTest();

	RunTest();
			
	return 0;

	}