'
' CSCM delivery packaging script 
' Carlos Puig
' Copyright 2008 Beceem, Inc 

Option Explicit

' ==============================================================
Dim strCMVersion, strConfiguration
Dim strBaseRelArray(10), strBaseRelease, strLibVersion
Dim iNumBaseRel
Dim sQuote, strDevEnvCmd, strZipCmd
Dim bolIncludeQtClient

' --------------------------------------------------------------
' EDIT THESE NAMES each time
' --------------------------------------------------------------
' These are global variables
strCMVersion = "1.1.5.1"

' All of these MUST end in '-lib-' followed by the library version number
strBaseRelArray(0) = "BCSM250-Rel5.2.6.6-lib-5.2.0628050017"
strBaseRelArray(1) = "BCSM250-Rel5.2.7.2-lib-5.2.84"
iNumBaseRel = 2

' Build Qt Client 
bolIncludeQtClient = false

' Source and destination directories
strDstTopDir = "C:\Perforce"
strSrcTopDir = strDstTopDir + "\CSCM"

' Configuration to put into installer (debug or release)
strConfiguration = "release"

' Commands
sQuote = """"
strDevEnvCmd = sQuote & "c:\Program Files\Microsoft Visual Studio 8\Common7\IDE\devenv.exe" & sQuote
strZipCmd = "c:\Software\util\usr\local\wbin\zip.exe"

' ==============================================================
Dim objFSO, objWsh

' Global file object
Set objFSO = CreateObject("Scripting.FileSystemObject")
Set objWsh = CreateObject("WSCript.shell")

' ---------------------------------------------------------
' Include the script function library
' ---------------------------------------------------------

Dim strLibraryPath     ' Script library file path
Dim objIncludeFile     ' Include file object
Dim strIncludeText     ' Include file text

strLibraryPath = strSrcTopDir & "\BeceemCSCM\Script\Script_function_library.vbs"
If Not objFSO.FileExists(strLibraryPath) Then
	WScript.Echo "ERROR: Can't find library file " & strLibraryPath
	WScript.Quit(1)
End If
set objIncludeFile = objFSO.OpenTextFile(strLibraryPath,1)
strIncludeText = objIncludeFile.ReadAll
objIncludeFile.close
ExecuteGlobal strIncludeText 

' ==============================================================

Dim strInternalRelease
Dim strDstTopDir, strSrcTopDir
Dim strSrcSupDir, strSrcEAPDir, strSrcCSCMDir, strSrcCmInstDir, strSrcQtDir
Dim strTmpBldDir, strCMVersionDir, strDstRelDir, strDstWin32Dir
Dim nPkg, n

' Define top release directory
strInternalRelease = "CM_Internal_Release_" & strCMVersion & "_" & DateTimeStamp()
strDstTopDir = strDstTopDir & "\" & strInternalRelease

' Define principal sub-directories
strSrcSupDir = strSrcTopDir & "\wpa_supplicant"
strSrcEAPDir = strSrcTopDir & "\BeceemEAPSupplicant"
strSrcCSCMDir = strSrcTopDir & "\BeceemCSCM"
strSrcCmInstDir = strSrcTopDir & "\BeceemCM-Installer"
If bolIncludeQtClient then
	strSrcQtDir = strSrcTopDir & "\QtClient"
End If 
strTmpBldDir = strSrcTopDir & "\temp-build"

' Create the top folder
If objFSO.FolderExists(strDstTopDir) Then
	If MsgBox(strDstTopDir & " exists. Delete this folder?", vbYesNo) = vbYes Then
		DeleteFolderNotify strDstTopDir, True, True
	Else
		WScript.Quit(1)
	End If
End If
CreateFolderNotify strDstTopDir, True, True

' Check the releases
For nPkg = 0 To iNumBaseRel - 1
	If InStr(1, strBaseRelArray(nPkg), "lib", 1) = 0 then
		MsgBox("Release name must end in lib-<version number>: " & strBaseRelArray(nPkg))
	End If
Next

Dim bolDevelMode
bolDevelMode = False

If Not bolDevelMode Then

	' Create an empty temporary build directory
	DeleteFolderNotify strTmpBldDir, True, False
	CreateFolderNotify strTmpBldDir, True, True
	
	' Build the Qt client and tools
	If bolIncludeQtClient then
		BuildQtClient()
	End if
	
End If

' Build the EAP supplicant installer
BuildEAPSupplicant()

' Build for each release
For nPkg = 0 To iNumBaseRel - 1

	' Define variables
	strCMVersionDir = "CM-" & strCMVersion
	strBaseRelease = strBaseRelArray(nPkg)
	n = InStr(1, strBaseRelease, "lib", 1)
	strLibVersion = Mid(strBaseRelease, n+4, Len(strBaseRelease))
	
	' Create Win32 release directory now
	strDstRelDir   = strDstTopDir & "\" & strBaseRelease
	strDstWin32Dir = strDstRelDir & "\Win32"
	DeleteFolderNotify strDstRelDir, True, False
	DeleteFolderNotify strDstWin32Dir, True, False
	CreateFolderNotify strDstRelDir, True, True
	CreateFolderNotify strDstWin32Dir, True, True
	
	' Build CSCM solution
	BuildBeceemCSCM(strBaseRelease)
	
	' Build the CM Installer solution
	BuildCMInstaller(strBaseRelease)
	
	' Clean the BeceemCSCM folder
	WScript.Echo ""
	WScript.Echo "Cleaning the BeceemCSCM folder"
	CleanCSCM(strSrcCSCMDir)
	
	' Assemble the release package
	BuildPackage(strBaseRelease)
	
Next 

' Delete the EAP supplicant build directory
If Not bolDevelMode then
	DeleteFolderNotify strTmpBldDir, True, False
End if

WScript.Quit(0)

' --------------------------------------------------------------
' Build Gui Client and Tools
' --------------------------------------------------------------

sub BuildQtClient

	Dim strLogFileName, strLogFilePath, strCmdLine
	
	' Clean the QtClient and Tools
	WScript.Echo ""
	WScript.Echo "Cleaning the Qt Client Tools folders (ConfigFile_Reader and ConfigFile_Writer)"
	CleanQtClient(strSrcQtDir)
	
	' Build the CSCM_GUI_CLIENT solution
	WScript.Echo ""
	strLogFileName = strInternalRelease & "_CSCM_GUI_CLIENT_" & strConfiguration & "_build.log"
	strLogFilePath = strTmpBldDir & "\" & strLogFileName
	WScript.Echo "CSCM_GUI_CLIENT " & strConfiguration & " build - logging to " & strLogFilePath
	strCmdLine = strDevEnvCmd & " " & strSrcQtDir & "\CSCM_GUI_CLIENT\CSCM_GUI_CLIENT.sln /Rebuild " & strConfiguration & " /Out " & strLogFilePath
	WScript.Echo "Running " & strCmdLine
	objWsh.Run strCmdLine, 1, 1
	
	' Build the ConfigFile_Reader solution
	WScript.Echo ""
	strLogFileName = strInternalRelease & "_ConfigFile_Reader_" & strConfiguration & "_build.log"
	strLogFilePath = strTmpBldDir & "\" & strLogFileName
	WScript.Echo "ConfigFile_Reader " & strConfiguration & " build - logging to " & strLogFilePath
	strCmdLine = strDevEnvCmd & " " & strSrcQtDir & "\ConfigFile_Reader\config_CLI.sln /Rebuild " & strConfiguration & " /Out " & strLogFilePath
	WScript.Echo "Running " & strCmdLine
	objWsh.Run strCmdLine, 1, 1
	
	' Build the ConfigFile_Writer solution
	WScript.Echo ""
	strLogFileName = strInternalRelease & "_ConfigFile_Writer_" & strConfiguration & "_build.log"
	strLogFilePath = strTmpBldDir & "\" & strLogFileName
	WScript.Echo "ConfigFile_Writer " & strConfiguration & " build - logging to " & strLogFilePath
	strCmdLine = strDevEnvCmd & " " & strSrcQtDir & "\ConfigFile_Writer\Carrier.sln /Rebuild " & strConfiguration & " /Out " & strLogFilePath
	WScript.Echo "Running " & strCmdLine
	objWsh.Run strCmdLine, 1, 1
	
End sub

' --------------------------------------------------------------
' Build EAP supplicant for all releases
' --------------------------------------------------------------

Function BuildEAPSupplicant

	dim strCmdLine, strEAPReleaseDir, strBuildLogFileName, strBuildLogFilePath
	
	' ==================================================================================
	' Build wpa supplicant library (eap_supplicant.dll)
	' ==================================================================================
	
	' Clean the wpa_supplicant folder
	WScript.Echo ""
	WScript.Echo "Cleaning the wpa_supplicant folder"
	CleanWpaSupplicant(strSrcSupDir)
	
	' Build the EAP Supplicant
	WScript.Echo ""
	WScript.Echo "Building the wpa supplicant libraries"
	strBuildLogFileName = strInternalRelease & "_wpa_supplicant_build.log"
	objWsh.CurrentDirectory = strSrcSupDir
	objWsh.Run "cmd /C c:\Software\msys\bin\make > " & strBuildLogFileName & " 2>&1", 9, True
	
	' Save the results in a build directory, so we can clean the source directory
	CopyDirFile strSrcSupDir, strTmpBldDir, "eap_supplicant.dll"
	CopyDirFile strSrcSupDir, strTmpBldDir, "eap_supplicant.lib"
	CopyDirFile strSrcSupDir, strTmpBldDir, strBuildLogFileName
	
	' Clean the wpa_supplicant folder
	WScript.Echo ""
	WScript.Echo "Cleaning the wpa_supplicant folder"
	CleanWpaSupplicant(strSrcSupDir)
	
	' ==================================================================================
	' Build Beceem EAP Supplicant Engine & Installer
	' ==================================================================================
		
	' Clean the EAP Supplicant Installer folder
	WScript.Echo ""
	WScript.Echo "Cleaning the Beceem EAP Supplicant folder"
	CleanBeceemEAPSupplicant(strSrcEAPDir)	
	
	' Copy the EAP supplicant library .dll's to the EAPSupplicantInstaller directory
	WScript.Echo ""
	WScript.Echo "Copying EAP supplicant .lib files"	

	strEAPReleaseDir = strSrcEAPDir & "\Release"
	CopyDirFile strTmpBldDir, strEAPReleaseDir, "eap_supplicant.dll"
	CopyDirFile strTmpBldDir, strEAPReleaseDir, "eap_supplicant.lib"
	
	' Build the EAPSupplicantInstaller solution
	WScript.Echo ""
	strBuildLogFileName = strInternalRelease & "_Beceem_EAP_Supplicant_" & strConfiguration & "_build.log"
	strBuildLogFilePath = strTmpBldDir & "\" & strBuildLogFileName
	WScript.Echo "BeceemEAPSupplicant " & strConfiguration & " build - logging to " & strBuildLogFilePath
	strCmdLine = strDevEnvCmd & " " & strSrcEAPDir & "\EAPSupplicant.sln /Rebuild " & strConfiguration & " /Out " & strBuildLogFilePath
	WScript.Echo "Running " & strCmdLine
	objWsh.Run strCmdLine, 1, 1
	
	' Save the the openssl libraries and Beceem EAP Supplicant installer to the temporary build directory
	CopyDirFile strEAPReleaseDir, strTmpBldDir, "BeceemEAPSupplicant.msi"
	
	' Clean the Beceem EAP Supplicant Installer folder
	WScript.Echo ""
	WScript.Echo "Cleaning the EAP Supplicant Installer folder"
	CleanBeceemEAPSupplicant(strSrcEAPDir)	
	
End Function

' --------------------------------------------------------------
' Build Beceem CSCM for a specific release
' --------------------------------------------------------------

Function BuildBeceemCSCM(strBaseRel)

	Dim n, folder, files, file
	Dim strSrcRelDir

	Dim strSrcIncDir, strDstIncDir
	Dim strBuildLogFile
	Dim strCmdLine, strMessage, strZipArchive
	Dim oExec

	' Define source sub-folders
	strSrcRelDir   = strSrcTopDir & "\" & strBaseRel
	strSrcIncDir   = strSrcRelDir & "\include"

	' Create destination sub-folders
	strDstIncDir  = strSrcCSCMDir & "\API_include"
	
	' ==================================================================================
	' Build BeceemCSCM
	' ==================================================================================
	
	' Clean the BeceemCSCM folder
	WScript.Echo ""
	WScript.Echo "Cleaning the BeceemCSCM folder"
	CleanCSCM(strSrcCSCMDir)
	
	' Copy the header files and library .dll to the BeceemCSCM directory
	WScript.Echo ""
	WScript.Echo "Copying API header and library files"
    set	folder = objFSO.GetFolder(strDstIncDir)
    Set files = folder.Files
	For Each file In files
		If StrComp(file.Name, "LibraryVersion.h", vbTextCompare) then
			CopyDirFile strSrcIncDir, strDstIncDir, file.Name
		End if
	Next	
	CopyDirFile strSrcRelDir, strDstIncDir, "LibraryVersion.h"
	CopyDllNotify strSrcRelDir & "\libxvi010", strSrcCSCMDir & "\", True
	
	' Copy the EAP supplicant library .dll's to the BeceemCSCM directory
	WScript.Echo ""
	WScript.Echo "Copying EAP supplicant library files"	
	CopyDllNotify strTmpBldDir & "\eap_supplicant", strSrcCSCMDir & "\", True
		
	' Build the BeceemCSCM solution
	WScript.Echo ""
	strBuildLogFile = strDstWin32Dir & "\" & strInternalRelease & "_Beceem_CSCM_" & strConfiguration & "_build.log"
	WScript.Echo "BeceemCSCM " & strConfiguration & " build - logging to " & strBuildLogFile
	strCmdLine = strDevEnvCmd & " " & strSrcCSCMDir & "\BeceemCSCM.sln /Rebuild " & strConfiguration & " /Out " & strBuildLogFile
	WScript.Echo "Running " & strCmdLine
	objWsh.Run strCmdLine, 1, 1
	
End Function

' --------------------------------------------------------------
' Build CM Installer for a specific release
' --------------------------------------------------------------

Function BuildCMInstaller(strBaseRel)

	Dim n, folder, files, file
	Dim strSrcRelDir

	Dim strSrcIncDir, strDstIncDir
	Dim strBuildLogFile
	Dim strCmdLine, strMessage, strZipArchive
	Dim oExec

	' Define source sub-folders
	strSrcRelDir   = strSrcTopDir & "\" & strBaseRel
	strSrcIncDir   = strSrcRelDir & "\include"
	
	' ==================================================================================
	' Build CM Installer
	' ==================================================================================
	
	' Clean the CM Installer folder
	WScript.Echo ""
	WScript.Echo "Cleaning the CM Installer folder"
	CleanCMInstaller(strSrcCmInstDir)
	
	' Build the CM Installer solution
	WScript.Echo ""
	strBuildLogFile = strDstWin32Dir & "\" & strInternalRelease & "_Beceem_CM_Installer_" & strConfiguration & "_build.log"
	WScript.Echo "BeceemCM-Installer " & strConfiguration & " build - logging to " & strBuildLogFile
	strCmdLine = strDevEnvCmd & " " & strSrcCmInstDir & "\BeceemCM-Installer-Devel.sln /Rebuild " & strConfiguration & " /Out " & strBuildLogFile
	WScript.Echo "Running " & strCmdLine
	objWsh.Run strCmdLine, 1, 1
	
	' Copy CM installer
	WScript.Echo "Copying CM installer"
	CopyFileToFileNotify strSrcCmInstDir & "\" & strConfiguration & "\BeceemCM.msi", _
				 strDstWin32Dir & "\BeceemCM_" & strCMVersion & "_lib_" & strLibVersion & "_Installer.msi", True, True
	
	' Clean the CM Installer folder
	WScript.Echo ""
	WScript.Echo "Cleaning the CM Installer folder"
	CleanCMInstaller(strSrcCmInstDir)
	
End Function

' ==================================================================================
' Final package assembly steps
' ==================================================================================

Function BuildPackage(strBaseRel)

	Dim n
	Dim strCmdLine
	Dim strDstSourceDir, strDstLinuxDir, strDstDocDir
	Dim strSrcCSCMDocDir, strSrcEAPDocDir
	
	' Create remaining destination directories for this release
	strDstSourceDir = strDstRelDir  & "\" & strCMVersionDir
	strDstLinuxDir  = strDstRelDir  & "\Linux"
	strDstDocDir    = strDstRelDir  & "\Doc"
	
	DeleteFolderNotify strDstSourceDir, True, False
	DeleteFolderNotify strDstLinuxDir, True, False
	DeleteFolderNotify strDstDocDir, True, False
	
	CreateFolderNotify strDstSourceDir, True, True
    CreateFolderNotify strDstLinuxDir, True, True
	CreateFolderNotify strDstDocDir, True, True
	
	strSrcCSCMDocDir = strSrcCSCMDir & "\Doc"
	strSrcEAPDocDir  = strSrcEAPDir  & "\Doc"
	
	' Copy Doc files
	WScript.Echo ""
	WScript.Echo "Copying Doc files"
	CopyFileToFolderNotify strSrcCSCMDocDir & "\*.pdf", strDstDocDir, True
	CopyFileToFolderNotify strSrcEAPDocDir  & "\*.pdf", strDstDocDir, True
	
	' Copy source files
	WScript.Echo ""
	CopyDirFile  strSrcTopDir, strDstSourceDir, "CM_Release_Log.doc"
	CopyDirFile  strSrcTopDir, strDstSourceDir, "CSCM_Build_Package.vbs"
	CopyDirFile  strSrcTopDir, strDstSourceDir, "build.sh"
	CopyDirFile  strSrcTopDir, strDstSourceDir, "install.sh"
	
	WScript.Echo ""
	WScript.Echo "Copying BeceemCSCM folder"
	CopyFolderNotify strSrcCSCMDir, strDstSourceDir & "\BeceemCSCM", True
	DeleteFolderNotify strDstSourceDir & "\BeceemCSCM\debug",   True, False
	DeleteFolderNotify strDstSourceDir & "\BeceemCSCM\debug-malloc", True, False
	DeleteFolderNotify strDstSourceDir & "\BeceemCSCM\release", True, False
	DeleteFolderNotify strDstSourceDir & "\BeceemCSCM\Doc",     True, False
	
	WScript.Echo ""
	WScript.Echo "Copying wpa_supplicant folder"
	CopyFolderNotify strSrcSupDir, strDstSourceDir & "\wpa_supplicant", True
	
	WScript.Echo ""
	WScript.Echo "Copying BeceemEAPSupplicant folder"
	CopyFolderNotify strSrcEAPDir, strDstSourceDir & "\BeceemEAPSupplicant", True
	DeleteFolderNotify strDstSourceDir & "\BeceemEAPSupplicant\debug",   True, False
	DeleteFolderNotify strDstSourceDir & "\BeceemEAPSupplicant\release", True, False
	DeleteFolderNotify strDstSourceDir & "\BeceemEAPSupplicant\Doc",     True, False
	
	' Build Linux zip file (contains source for CSCM, wpa_supplicant, and BeceemEAPSupplicant only)
	WScript.Echo ""
	WScript.Echo "Building the Linux source tarball"
	objWsh.CurrentDirectory = strDstRelDir
	WScript.Echo "Moved to " & objWsh.CurrentDirectory
	' strZipArchive = strDstLinuxDir & "\" & "\BeceemCSCM_" & strCMVersion & "_lib_" & strLibVersion & ".tar"
	strCmdLine = strZipCmd & " -r -v " & strCMVersionDir & ".zip " & strCMVersionDir
	WScript.Echo "Running " & strCmdLine
	objWsh.Run strCmdLine,1,True
	WScript.Echo "Moving " & strCMVersionDir & ".zip to " & strDstLinuxDir
	CopyFileToFileNotify strCMVersionDir & ".zip", strDstLinuxDir & "\" & strCMVersionDir & "_lib_" & strLibVersion & ".zip", True, True
	DeleteFileNotify strCMVersionDir & ".zip", True, True
	
	' Copy EAPSupplicant installer
	WScript.Echo "Copying EAP Supplicant installer"
	CopyFileToFileNotify strTmpBldDir & "\BeceemEAPSupplicant.msi", _
				 strDstWin32Dir & "\BeceemEAPSupplicant_" & strCMVersion & "_Installer.msi", True, True
	
	If bolIncludeQtClient then
		WScript.Echo ""
		WScript.Echo "Copying QtClient folders"
		CopyQtClient(strDstSourceDir & "\QtClient")
	End if
	
	WScript.Echo ""
	WScript.Echo "Copying CM Installer folders"
	' These have already been cleaned in BuildCMInstaller()
	CopyFolderNotify strSrcCmInstDir, strDstSourceDir & "\BeceemCM-Installer", True
	
	' Copy all the build log files
	CopyFileToFolderNotify strTmpBldDir + "\*log", strDstWin32Dir, True
	
End Function

Sub DeleteDebugReleaseFolders(strDir)

	DeleteFolderNotify strDir + "debug", True, False
	DeleteFolderNotify strDir + "release", True, False
	
End sub

Sub CleanQtClient(strSrcDir)
	
	Dim strSolDir
	
	strSolDir = strSrcDir & "\CSCM_GUI_CLIENT\"	
	CleanQtClientCommonDir strSolDir, "Debug"
	CleanQtClientCommonDir strSolDir, "Release"
	CleanProject strSolDir & "CSCM_CONFIG_LIB\", "CscmConfigFileHandler"
	CleanProject strSolDir & "CSCM_WIFI\", "CscmWiFi"
	CleanProject strSolDir & "CSCM_WIMAX_SOCKET\", "CscmWimaxSocket"
	CleanProject strSolDir & "CSCM_GUI\", "CSCM_GUI"
	DeleteFilePattern strSolDir & "CSCM_GUI\CSCM_GUI\ui_*.h"
	DeleteFilePattern strSolDir & "CSCM_GUI\CSCM_GUI\CscmGui.vcproj*user"
	CleanProject strSolDir, "MergeModule-CSCM_GUI_CLIENT"
	CleanSolution strSolDir
	
	strSolDir = strSrcDir & "\ConfigFile_Reader\"	
	CleanWinBinaries strSolDir & "debug\", True
	CleanWinBinaries strSolDir & "release\", True	
	CleanProject strSolDir, "config_CLI"
	CleanProject strSolDir, "MergeModule-config_CLI"
	CleanSolution strSolDir
	
	strSolDir = strSrcDir & "\ConfigFile_Writer\"	
	CleanWinBinaries strSolDir & "debug\", True
	CleanWinBinaries strSolDir & "release\", True	
	CleanProject strSolDir, "Carrier"
	CleanProject strSolDir, "MergeModule-Carrier"
	CleanSolution strSolDir
	
End Sub

Sub CopyQtClient(strDstQtDir)

	Dim strProjName, strSolName, strSrcSolDir, strDstSolDir
	
	strSrcSolDir = strSrcQtDir & "\CSCM_GUI_CLIENT"
	strDstSolDir = strDstQtDir & "\CSCM_GUI_CLIENT"
	
	CreateFolderNotify strDstQtDir, True, False
	CreateFolderNotify strDstSolDir, True, False
	
	CopyQtClientGuiProject "\CSCM_CONFIG_LIB", "\CscmConfigFileHandler", strDstQtDir
	CopyQtClientGuiProject "\CSCM_WIFI", "\CscmWiFi", strDstQtDir
	CopyQtClientGuiProject "\CSCM_WIMAX_SOCKET", "\CscmWimaxSocket", strDstQtDir
	CopyQtClientGuiProject "\CSCM_GUI", "\CSCM_GUI", strDstQtDir
	
	CopyQtClientProject "\CSCM_GUI_CLIENT\MergeModule-CSCM_GUI_CLIENT", strDstQtDir
	CopyQtClientProject "\CSCM_GUI_CLIENT\Test-Setup-CSCM_GUI_CLIENT", strDstQtDir
	CopyQtClientProject "\ConfigFile_Editor", strDstQtDir
	CopyQtClientProject "\ConfigFile_Reader", strDstQtDir
	CopyQtClientProject "\ConfigFile_Writer", strDstQtDir
	
	CopyFileToFolderNotify strSrcSolDir & "\*sln", strDstSolDir, True
	CopyFileToFolderNotify strSrcSolDir & "\*png", strDstSolDir, True
	CopyFileToFolderNotify strSrcSolDir & "\*dat", strDstSolDir, True	

	CopyQtClientBinFolders strDstQtDir
	
	WScript.Echo "Cleaning the copied Qt Client folders"
	CleanQtClient(strDstQtDir)
	
	
End Sub

Sub CopyQtClientProject (strSolSubDir, strDstDir)

	Dim strSrcSolDir, strDstSolDir
	strSrcSolDir = strSrcQtDir & strSolSubDir
	strDstSolDir = strDstDir & strSolSubDir
	CreateFolderNotify strDstSolDir, True, False
	CopyFolderNotify strSrcSolDir, strDstSolDir, True
	
End Sub


Sub CopyQtClientGuiProject (strSol1Name, strSol2Name, strDstQtDir)

	Dim strSrcSolDir, strDstSolDir
	
	strSrcSolDir = strSrcQtDir & "\CSCM_GUI_CLIENT"
	strDstSolDir = strDstQtDir & "\CSCM_GUI_CLIENT"
	CreateFolderNotify strDstSolDir & strSol1Name, True, False
	CreateFolderNotify strDstSolDir & strSol1Name & strSol2Name, True, False
	CopyFolderNotify strSrcSolDir & strSol1Name & strSol2Name, _
				     strDstSolDir & strSol1Name & strSol2Name, True
End Sub

Sub CopyQtClientBinFolders (strDstQtDir)

	Dim strSrcBinDir, strDstBinDir
	
	strSrcBinDir = strSrcQtDir & "\CSCM_GUI_CLIENT\bin\Release"
	strDstBinDir = strDstQtDir & "\CSCM_GUI_CLIENT\bin\"
	
	CreateFolderNotify strDstBinDir, True, False
	CreateFolderNotify strDstBinDir & "\Common\", True, False
	CreateFolderNotify strDstBinDir & "\Help\", True, False
	CreateFolderNotify strDstBinDir & "\Skins\", True, False
	
	CopyFileToFolderNotify strSrcBinDir & "\Common\Cscm_English*", strDstBinDir & "\Common\", True	
	CopyFileToFolderNotify strSrcBinDir & "\Help\Cscm_Help.chm", strDstBinDir & "\Help\", True
	CopyFolderNotify strSrcBinDir & "\Skins", strDstBinDir & "\Skins", True	

End sub

Sub CleanQtClientCommonDir(strSolDir, strType)

	Dim strCommonDir
	
	strCommonDir = 	strSolDir &"Bin\" & strType & "\Common\"
	CleanWinBinaries strCommonDir, False
	DeleteFilePattern strCommonDir & "CscmConfigFileHandler.*"
	DeleteFilePattern strCommonDir & "CscmWiFi.*"
	DeleteFilePattern strCommonDir & "CscmWimaxSocket.*"
	DeleteFile strCommonDir & "CscmGui.exe"

End Sub 

Sub CleanCSCM(strSrcDir)
	
	Dim strSolDir
	
	strSolDir = strSrcDir & "\"
	
	CleanWinBinaries strSolDir & "debug\", False
	CleanWinBinaries strSolDir & "debug-malloc\", False
	CleanWinBinaries strSolDir & "release\", False	
	
	CleanProject strSolDir, "BeceemCSCM-Client"
	CleanProject strSolDir, "BeceemCSCM-Server"
	
	DeleteFilePattern strSolDir & "*.ncb"
	DeleteFilePattern strSolDir & "*.suo"
	DeleteFolder strSolDir & "debug-malloc"
	
End Sub

Sub CleanCMInstaller(strSrcDir)
	
	Dim strSolDir
	
	strSolDir = strSrcDir & "\"
	
	CleanWinBinaries strSolDir & "Debug\", True
	CleanWinBinaries strSolDir & "Release\", True	
	
	CleanProject strSolDir, "BeceemCM-Installer"
	
	CleanSolution strSolDir
	
End Sub

Sub CleanBeceemEAPSupplicant(strSrcDir)

	Dim strSolDir
	
	strSolDir = strSrcDir & "\"
	
	CleanWinBinaries strSolDir & "debug\", False
	DeleteFilePattern strSolDir & "debug\engine_beceem.*"
	CleanWinBinaries strSolDir & "release\", False
	DeleteFilePattern strSolDir & "release\engine_beceem.*"
	
	CleanProject strSolDir, "BeceemEngine"
	CleanProject strSolDir, "BeceemEngineTestApp"
	
	DeleteFilePattern strSolDir & "*.ncb"
	DeleteFilePattern strSolDir & "*.suo"

End sub

Sub CleanWpaSupplicant(strSrcDir)

	Dim strPrefix
	
	strPrefix = strSrcDir & "\"
	
	DeleteFileNotify strPrefix & "core", True, False
	DeleteFilePatternNotify strPrefix & "*.~", False
	DeleteFilePatternNotify strPrefix & "*.o", False
	DeleteFilePatternNotify strPrefix & "*.d", False
	DeleteFilePatternNotify strPrefix & "*.a", False
	DeleteFilePatternNotify strPrefix & "*.dll", False
	DeleteFilePatternNotify strPrefix & "*.exe", False
	DeleteFilePatternNotify strPrefix & "*.log", False
	DeleteFileNotify strPrefix & "eap_supplicant_debug.txt", True, False
	
End Sub

' ==================================================================================
' Miscellaneous utility functions
' ==================================================================================

Sub CleanWinBinaries(strBinDir, bolDeleteDll)

	DeleteFilePattern strBinDir & "*.exe"
	DeleteFilePattern strBinDir & "*.exp"
	DeleteFilePattern strBinDir & "*.msi"
	DeleteFilePattern strBinDir & "*.msm"
	DeleteFilePattern strBinDir & "*.ilk"
	DeleteFilePattern strBinDir & "*.pdb"
	DeleteFilePattern strBinDir & "*.txt"
	If bolDeleteDll Then
		DeleteFilePattern strBinDir & "*.dll"
		DeleteFilePattern strBinDir & "*.lib"
	End if

End Sub

' ---------------------------------------------
' Copy a file from one directory to another
Sub CopyDirFile (strSrcDir, strDstDir, strFileName)
	Dim strSrcPath, strDstPath
	strSrcPath = strSrcDir & "\" & strFileName
	strDstPath = strDstDir & "\" & strFileName
	WScript.Echo "Copying " & strFileName & " from " & strSrcDir & " to " & strDstDir
	CopyFileToFileNotify strSrcPath, strDstPath, True, True
End Sub

' ---------------------------------------------------------
' Checks for the existence or non-existence of a folder
' Returns false on error
Function CheckFolder(strFolder, bShouldExist) 

	' Check the source folders
	Dim bFolderExists
	
	bFolderExists = objFSO.FolderExists(strFolder)
	
	CheckFolder = true
	
	If bShouldExist And Not bFolderExists Then
		WScript.Echo "ERROR: Source folder '" & strFolder & "' does not exist."
		CheckFolder = false		
	ElseIf Not bShouldExist And bFolderExists then	
		WScript.Echo "ERROR: Source folder '" & strFolder & "' exists. Please delete it."
		CheckFolder = false		
	End If

End Function

' ---------------------------------------------------------
' Return current date and time
Function DateTimeStamp()
	Dim datToday, strDate, strHour, strMin , strTime
	datToday = Now
	strDate = CStr(Day(datToday)) & MonthName(Month(datToday), True) & CStr(Year(datToday))
	strHour = CStr(Hour(datToday))
	strMin = CStr(Minute(datToday))
	strTime = String(2 - Len(strHour), "0") & strHour & String(2-Len(strMin), "0") & strMin
	DateTimeStamp = strDate & "_" & strTime
End Function


