#!/bin/bash
#
# 	Beceem CM build script
#	Copyright 2008-2009 Beceem Communications, Inc
# 	July 2009
#

# -------------------------------------------------------------
# 	Prerequisites
# -------------------------------------------------------------
#   	The following libraries must already be installed 
#	on your system:
#		libssl (version 0.9.8b or later)
#		libcrypto
#		libpthread
#		librt
#		libxvi020
#
# 	The Beceem CM does not use the tgtxvi020 Beceem 
#	proxy application. 

# -------------------------------------------------------------
# 	Configuration section
# 	Adjust these settings as needed
# -------------------------------------------------------------

# if appropriate, define the following environment variables
# CROSS_COMPILE
# CROSS_TOOLCHAIN_DIR

# Beceem CM version
CM_VERSION=1.1.5

# Beceem CM source directory
CM_DIR=$(pwd)

#PLATFORM - the platform for which the CSCM/Supplicant is being built.
#Accepted values - mac, bcs5200, bcs5350, pc_linux
	case "$1" in
		"" )
		echo "usage... "
		echo "./build.sh PLATFORM [clean] [debug | nodebug]"
		echo "	PLATFORM = pc_linux | bcs5350 | bcs5200 | mac "
		exit 1
		;;

		pc_linux | bcs5350 | bcs5200 | mac )
		PLATFORM=$1
		;;
		
		* )
		echo  PLATFORM $1 Not supported.
		echo  Exiting!
		exit 1
		;;
	esac
# Select the components you want to build (y or n)
BUILD_EAP_SUPPLICANT=y
BUILD_ENGINE=y
BUILD_CLIENT=y
BUILD_SERVER=y

case "$2" in
	"" )
	case $PLATFORM in
		bcs5350 | bcs5200 )
		DEBUG=0
		;;
		
		* )
		DEBUG=1
		;;
	esac
	;;

	debug )
	DEBUG=1
	;;

	nodebug )
	DEBUG=0
	;;

	clean )
	echo Cleaning Library Components
	sleep 1
	echo done
	exit 0
	;;
esac

	
# -------------------------------------------------------------
#	Do not modify the script below this line
# -------------------------------------------------------------

TARGET_BIN_DIR=$CM_DIR/bin_${PLATFORM}/bin
TARGET_OBJ_DIR=$CM_DIR/bin_${PLATFORM}/obj

export PLATFORM
export CM_DIR
export TARGET_BIN_DIR
export TARGET_OBJ_DIR
export DEBUG

if [ $PLATFORM == mac ]; then
	LEXT=dylib
	LIBXVI_HEADERS_PATH=../Library/OSAL/Windows/include
else
    	LEXT=so
fi

if [ $PLATFORM == pc_linux ]; then
	LIBXVI_DIR=../Library/OSAL/Windows/bin_linux/bin
	LIBXVI_HEADERS_PATH=../Library/OSAL/Windows/include
fi

# Special handling for Maya platform when TOOLCHAIN_52XX and SDK_52XX are defined
if [ $PLATFORM == bcs5200 ]; then
	if [ -z "$TOOLCHAIN_52XX" ]; then
		echo Please define TOOLCHAIN_52XX for the bcs5200 target
		exit
	else
		CROSS_COMPILE=${TOOLCHAIN_52XX}/bin/arm-linux-uclibc-
		CROSS_TOOLCHAIN_DIR=$TOOLCHAIN_52XX
		export CROSS_COMPILE
		export CROSS_TOOLCHAIN_DIR
		if [ -n "$SDK_52XX" ]; then
			LIBXVI_DIR=${SDK_52XX}/src/52xx_src/WiMAXLibrary/bin_linux/bin
			LIBXVI_HEADERS_PATH=${SDK_52XX}/src/52xx_src/WiMAXLibrary/include
		else
			LIBXVI_DIR=${CM_DIR}/../WiMAXLibrary/bin_linux/bin
			LIBXVI_HEADERS_PATH=${CM_DIR}/../WiMAXLibrary/include
		fi
		export LIBXVI_DIR
	fi
fi



if [ $PLATFORM == bcs5350 ]; then
	if [ -z "$CROSS_TOOLCHAIN_DIR" ]; then
		echo Please define CROSS_TOOLCHAIN_DIR for the bcs5350 target
		exit
	else
		CROSS_COMPILE=${CROSS_TOOLCHAIN_DIR}/usr/bin/mips-linux-uclibc-
		LIBXVI_DIR=${CM_DIR}/../Library/bin_linux/bin
		LIBXVI_HEADERS_PATH=../Library/include
# create symlinks for OpenSSL Libs.
		ln -s libssl.so.0.9.8 ${CM_DIR}/../../lib/libssl.so
		ln -s libcrypto.so.0.9.8 ${CM_DIR}/../../lib/libcrypto.so

		export LIBXVI_DIR
		export CROSS_COMPILE
		export CROSS_TOOLCHAIN_DIR
	fi
fi

if [ -n "$LIBXVI_HEADERS_PATH" ]; then
	cp -rf $LIBXVI_HEADERS_PATH/*.h BeceemCSCM/API_include/.
fi

echo ================================
echo Building for plaform $PLATFORM
echo =================================

mkdir -p $TARGET_BIN_DIR
mkdir -p $TARGET_OBJ_DIR

if [ $BUILD_EAP_SUPPLICANT == y ]; then
	echo ======================================
	echo Building EAP supplicant 
	echo ======================================
	cd $CM_DIR/wpa_supplicant
	cp -v .config.linux .config
	make clean
	make 
	mv -v libeap_supplicant.$LEXT $TARGET_BIN_DIR
	if [ $DEBUG == 0 ]
	then
		${CROSS_COMPILE}strip $TARGET_BIN_DIR/libeap_supplicant.$LEXT
	fi
fi

if [ $BUILD_ENGINE == y ]; then
	echo ======================================
	echo Building Beceem cryptographic engine 
	echo ======================================
	cd $CM_DIR/BeceemEAPSupplicant/BeceemEngine
	make clean
	make 
	mv -v libengine_beceem.$LEXT $TARGET_BIN_DIR
	if [ $DEBUG == 0 ]
	then
		${CROSS_COMPILE}strip $TARGET_BIN_DIR/libengine_beceem.$LEXT
	fi
fi

if [ $BUILD_CLIENT == y ]; then
	echo ========================================
	echo Building client
	echo ========================================
	cd $CM_DIR/BeceemCSCM/BeceemCSCM-Client
	make clean
	make
	if [ $DEBUG == 0 ]
	then
		${CROSS_COMPILE}strip $TARGET_BIN_DIR/wimaxc
	fi
fi

if [ $BUILD_SERVER == y ]; then
	echo ========================================
	echo Building Server
	echo ========================================
	cd $CM_DIR/BeceemCSCM/BeceemCSCM-Server
	make clean
	make
	if [ $DEBUG == 0 ]
	then		
		${CROSS_COMPILE}strip $TARGET_BIN_DIR/wimaxd
	fi
fi

echo ========================================
echo Beceem CM build completed
echo ========================================
echo Build results are in $TARGET_BIN_DIR
echo 
echo Beceem CM build Summary

if [ $BUILD_EAP_SUPPLICANT == y ]; then
	if [ ! -f $TARGET_BIN_DIR/libeap_supplicant.$LEXT ]; then
		echo Building EAP supplicant libraries         FAILED
	else
		echo Building EAP supplicant libraries         SUCCESS
	fi
fi
if [ $BUILD_ENGINE == y ]; then
	if [ ! -f $TARGET_BIN_DIR/libengine_beceem.$LEXT ]; then
		echo Building Beceem cryptographic engine      FAILED
	else
		echo Building Beceem cryptographic engine      SUCCESS
	fi
fi
if [ $BUILD_CLIENT == y ]; then
	if [ ! -f $TARGET_BIN_DIR/wimaxc ]; then
		echo Building Client                           FAILED
	else
		echo Building Client                           SUCCESS
	fi
fi
if [ $BUILD_SERVER == y ]; then
	if [ ! -f $TARGET_BIN_DIR/wimaxd ]; then
		echo Building Server                           FAILED
	else
		echo Building Server                           SUCCESS
	fi
fi
echo ========================================

