#!/bin/sh
#
# 	Beceem CM installation script
#	Copyright 2008-2009 Beceem Communications, Inc
# 	July 2009
#

# -------------------------------------------------------------
# 	Prerequisites
# -------------------------------------------------------------
# build.sh must have run successfully before install.sh is run

# -------------------------------------------------------------
# 	Configuration section
# 	Adjust these settings as needed
# -------------------------------------------------------------

# Beceem CM version
CM_VERSION=1.1.4

# Beceem CM source directory
CM_DIR=$(pwd)

#Select the target platform
# TARGET = bcs5200, mac, and pc_linux have special handling. For all
#          other targets, this script should be modified as needed.
#TARGET=bcs5200
#TARGET=mac
TARGET=pc_linux

# Select the components you want to install (y or n)
INSTALL_EAP_SUPPLICANT=y
INSTALL_ENGINE=y
INSTALL_CLIENT=y
INSTALL_SERVER=y

# TFTP server directory, if used
# TFTP_DIR=/tftpboot

# -------------------------------------------------------------
#	Do not modify the script below this line
# -------------------------------------------------------------

TARGET_BIN_DIR=$CM_DIR/bin_${TARGET}/bin

if [ $TARGET == mac ]; then
	LEXT=dylib
	LIB_DIR=/usr/local/lib
	INSTALL_DIR=/usr/local/bin
	CONF_DIR=/etc
else
    LEXT=so
	# Special handling for Maya platform 
	if [ $TARGET == bcs5200 ]; then
		LIB_DIR=$TOOLCHAIN_52XX/usr/lib
		INSTALL_DIR=
		CONF_DIR=
	else
		LIB_DIR=/lib
		INSTALL_DIR=/usr/local/bin
		CONF_DIR=/etc
	fi
fi

echo ===================================
echo Installing for target $TARGET
# UID is a bash shell read-only variable
if [ $UID == "0" ]; then
	SUDO=
	echo Running as root
else
	SUDO=sudo
	echo Using 'sudo' to install files 
fi
echo ===================================

if [ -d "$TARGET_BIN_DIR" ]; then
	echo Copying binary files from $TARGET_BIN_DIR
else
	echo Binary directory $TARGET_BIN_DIR not found
	exit 1
fi

if [ $INSTALL_EAP_SUPPLICANT == y ]; then
	echo =========================
	echo Installing EAP supplicant 
	echo =========================
	$SUDO cp -v $TARGET_BIN_DIR/libeap_supplicant.$LEXT $LIB_DIR/libeap_supplicant.$LEXT.$CM_VERSION
	cd $LIB_DIR
	$SUDO ln -sf libeap_supplicant.$LEXT.$CM_VERSION  libeap_supplicant.$LEXT
fi

if [ $INSTALL_ENGINE == y ]; then
	echo ======================================
	echo Installing Beceem cryptographic engine 
	echo ======================================
	$SUDO cp -v $TARGET_BIN_DIR/libengine_beceem.$LEXT $LIB_DIR/libengine_beceem.$LEXT.$CM_VERSION
	cd $LIB_DIR
	$SUDO ln -sf libengine_beceem.$LEXT.$CM_VERSION  libengine_beceem.$LEXT
fi

if [ $TARGET == pc_linux -o $TARGET == mac ]; then
	echo ========================================
	echo Copying CSCM executables to $INSTALL_DIR
	echo ========================================
	if [ $INSTALL_CLIENT == y ]; then
		$SUDO cp -v $TARGET_BIN_DIR/wimaxc $INSTALL_DIR
	fi
	if [ $INSTALL_SERVER == y ]; then
		$SUDO cp -v $TARGET_BIN_DIR/wimaxd $INSTALL_DIR
	fi
	if [ ! -f $CONF_DIR/wimaxd.conf ]; then
		echo ========================================
		echo Copying wimaxd.conf to $CONF_DIR
		echo ========================================
		$SUDO cp -v $CM_DIR/BeceemCSCM/wimaxd.conf $CONF_DIR
	fi
fi

if [ -n "$TFTP_DIR" ]; then
	echo ===========================================
	echo Copying BCS5200 binaries to TFTP directory
	echo ===========================================
	$SUDO cp -v $CM_DIR/BeceemCSCM/wimaxd.conf $TFTP_DIR
	cd $TARGET_BIN_DIR
	if [ $INSTALL_EAP_SUPPLICANT = y ]; then
		$SUDO cp -v libeap_supplicant.so $TFTP_DIR
	fi
	if [ $INSTALL_ENGINE = y ]; then
		$SUDO cp -v libengine_beceem.so	 $TFTP_DIR
	fi
	if [ $INSTALL_CLIENT = y ]; then
		$SUDO cp -v wimaxc 				 $TFTP_DIR
	fi
	if [ $INSTALL_SERVER = y ]; then
		$SUDO cp -v wimaxd 				 $TFTP_DIR
	fi
fi

echo ========================================
echo Beceem CM installation completed
echo ========================================


